;; Generated package description from xref.el  -*- no-byte-compile: t -*-
(define-package "xref" "1.3.2" "Cross-referencing commands" '((emacs "26.1")) :commit "766108f48db29f766908c728969f78d8e896171e" :url "https://elpa.gnu.org/packages/xref.html")
